@@ -5,20 +5,19 @@ use App::SimulateReads::Base 'class';
 
 extends 'App::SimulateReads::Command::QualityDB';
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use constant {
 	TYPE_OPT => ['raw', 'fastq']
 };
 
-sub opt_spec {
-	'help|h',
-	'man|M',
+override 'opt_spec' => sub {
+	super,
 	'verbose|v',
 	'quality-profile|q=s',
 	'read-size|r=i',
 	'source|s=s'
-}
+};
 
 sub _default_opt {
 	'verbose' => 0,
@@ -26,15 +25,6 @@ sub _default_opt {
 	'source'  => 'not defined'
 }
 
-sub _fill_opts {
-	my ($self, $opts) = @_;
-	my %default_opt = $self->_default_opt;
-
-	for my $opt (keys %default_opt) {
-		$opts->{$opt} = $default_opt{$opt} if not exists $opts->{$opt};
-	}
-}
-
 sub validate_args {
 	my ($self, $args) = @_;
 	my $file = shift @$args;
@@ -54,7 +44,8 @@ sub validate_args {
 
 sub validate_opts {
 	my ($self, $opts) = @_;
-	$self->_fill_opts($opts);
+	my %default_opt = $self->_default_opt;
+	$self->fill_opts($opts, \%default_opt);
 
 	if (not exists $opts->{'quality-profile'}) {
 		die "Option 'quality-profile' not defined\n";
@@ -72,7 +63,9 @@ sub validate_opts {
 sub execute {
 	my ($self, $opts, $args) = @_;
 	my $file = shift @$args;
-	$self->_fill_opts($opts);
+
+	my %default_opt = $self->_default_opt;
+	$self->fill_opts($opts, \%default_opt);
 
 	# Set if user wants a verbose log
 	$LOG_VERBOSE = $opts->{verbose};
@@ -108,7 +101,7 @@ App::SimulateReads::Command::QualityDB::Add - qualitydb subcommand class. Add a
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
