@@ -5,15 +5,14 @@ use App::SimulateReads::Base 'class';
 
 extends 'App::SimulateReads::Command::QualityDB';
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
-sub opt_spec {
-	'help|h',
-	'man|M',
+override 'opt_spec' => sub {
+	super,
 	'verbose|v',
 	'quality-profile|q=s',
 	'read-size|r=i'
-}
+};
 
 sub validate_args {
 	my ($self, $args) = @_;
@@ -52,7 +51,7 @@ App::SimulateReads::Command::QualityDB::Remove - qualitydb subcommand class. Rem
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
